@@ -32,19 +32,13 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             };
 
             use std::sync::Arc;
-            use checkout_core::dropshot::ApiEndpoint;
-            use serde::{Deserialize, Serialize};
-            use schemars::JsonSchema;
+            use checkout_core::dropshot;
+            use checkout_core::server::CreateRequest;
 
             pub struct ServerContext {
                 pub context_provider: super::#name
             }
 
-            #[derive(Serialize, Deserialize, JsonSchema)]
-            pub struct CreateRequest {
-                currency: Currency,
-            }
-
             #[endpoint {
                 method = POST,
                 path = "/create",
